package com.ruoyi.bst.orderProd.domain;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.constant.DictType;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.system.valid.DictValid;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.math.BigDecimal;

/**
 * 订单产品对象 bst_order_prod
 *
 * @author ruoyi
 * @date 2024-12-17
 */
@Data
public class OrderProd extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    private Long id;

    @Excel(name = "订单ID")
    @ApiModelProperty("订单ID")
    private Long orderId;

    @Excel(name = "加工方式", dictType = DictType.ORDER_PROD_WORK_TYPE, comboReadDict = true)
    @ApiModelProperty("加工方式")
    @DictValid(type = DictType.ORDER_PROD_WORK_TYPE, message = "非法的产品加工方式")
    @NotBlank(message = "产品加工方式不能为空", groups = {ValidGroup.Create.class})
    private String workType;

    @Excel(name = "是否成品")
    @ApiModelProperty("是否成品")
    private Boolean isEnd;

    @Excel(name = "物料编号")
    @ApiModelProperty("物料编号")
    @Size(max = 200, message = "物料编号长度不能超过200个字符")
    private String materialNo;

    @Excel(name = "图片", cellType = Excel.ColumnType.IMAGE)
    @ApiModelProperty("图片")
    private String picture;

    @Excel(name = "产品名称")
    @ApiModelProperty("产品名称")
    @Size(max = 200, message = "产品名称长度不能超过200个字符")
    @NotBlank(message = "产品名称不能为空", groups = {ValidGroup.Create.class})
    private String name;

    @Excel(name = "规格")
    @ApiModelProperty("规格")
    @Size(max = 50, message = "规格长度不能超过50个字符")
    private String spec;

    @Excel(name = "订单数量")
    @ApiModelProperty("订单数量")
    @Min(value = 1, message = "订单数量不能小于1")
    @NotNull(message = "订单数量不能为空", groups = {ValidGroup.Create.class})
    private BigDecimal num;

    @Excel(name = "排序")
    @ApiModelProperty("排序")
    private Integer sort;

    @Excel(name = "处理方式")
    @ApiModelProperty("处理方式")
    @Size(max = 200, message = "处理方式长度不能超过200个字符")
    private String handleWay;

    @Excel(name = "效果/包装尺寸")
    @ApiModelProperty("效果/包装尺寸")
    @Size(max = 200, message = "效果/包装尺寸长度不能超过200个字符")
    private String effect;

    @Excel(name = "颜色")
    @ApiModelProperty("颜色")
    @Size(max = 200, message = "颜色长度不能超过200个字符")
    private String color;

    @Excel(name = "球盖颜色/外箱尺寸")
    @ApiModelProperty("球盖颜色/外箱尺寸")
    @Size(max = 200, message = "球盖颜色/外箱尺寸长度不能超过200个字符")
    private String coverColor;

    @Excel(name = "装量")
    @ApiModelProperty("装量")
    @Min(value = 1, message = "装量不能小于1")
    @NotNull(message = "装量不能为空", groups = {ValidGroup.Create.class})
    private Integer contentNum;

    @Excel(name = "序号")
    @ApiModelProperty("序号")
    private String no;

    @Excel(name = "加工商")
    @ApiModelProperty("加工商名称")
    private String workName;

    @Excel(name = "备注")
    @ApiModelProperty("备注")
    @Size(max = 200, message = "备注长度不能超过200个字符")
    private String remark;

}
