package com.ruoyi.bst.prodProcess.service.impl;

import com.ruoyi.bst.prodProcess.domain.ProdProcess;
import com.ruoyi.bst.prodProcess.domain.ProdProcessQuery;
import com.ruoyi.bst.prodProcess.domain.ProdProcessVO;
import com.ruoyi.bst.prodProcess.mapper.ProdProcessMapper;
import com.ruoyi.bst.prodProcess.service.IProdProcessService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * 产品工序Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-17
 */
@Service
public class ProdProcessServiceImpl implements IProdProcessService
{
    @Autowired
    private ProdProcessMapper prodProcessMapper;

    /**
     * 查询产品工序
     *
     * @param id 产品工序主键
     * @return 产品工序
     */
    @Override
    public ProdProcessVO selectProdProcessById(Long id)
    {
        return prodProcessMapper.selectProdProcessById(id);
    }

    /**
     * 查询产品工序列表
     *
     * @param prodProcess 产品工序
     * @return 产品工序
     */
    @Override
    public List<ProdProcessVO> selectProdProcessList(ProdProcessQuery prodProcess)
    {
        return prodProcessMapper.selectProdProcessList(prodProcess);
    }

    /**
     * 新增产品工序
     *
     * @param prodProcess 产品工序
     * @return 结果
     */
    @Override
    public int insertProdProcess(ProdProcess prodProcess)
    {
        prodProcess.setCreateTime(DateUtils.getNowDate());
        return prodProcessMapper.insertProdProcess(prodProcess);
    }

    /**
     * 修改产品工序
     *
     * @param prodProcess 产品工序
     * @return 结果
     */
    @Override
    public int updateProdProcess(ProdProcess prodProcess)
    {
        return prodProcessMapper.updateProdProcess(prodProcess);
    }

    /**
     * 批量删除产品工序
     *
     * @param ids 需要删除的产品工序主键
     * @return 结果
     */
    @Override
    public int deleteProdProcessByIds(Long[] ids)
    {
        return prodProcessMapper.deleteProdProcessByIds(ids);
    }

    /**
     * 删除产品工序信息
     *
     * @param id 产品工序主键
     * @return 结果
     */
    @Override
    public int deleteProdProcessById(Long id)
    {
        return prodProcessMapper.deleteProdProcessById(id);
    }

    @Override
    public List<ProdProcessVO> selectByOrderId(Long orderId) {
        if (orderId == null) {
            return Collections.emptyList();
        }
        ProdProcessQuery query = new ProdProcessQuery();
        query.setOrderId(orderId);
        return this.selectProdProcessList(query);
    }

    @Override
    public int batchUpdate(List<? extends ProdProcess> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return prodProcessMapper.batchUpdate(list);
    }

    @Override
    public int batchLogicDel(List<? extends ProdProcess> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return prodProcessMapper.logicDel(CollectionUtils.map(list, ProdProcess::getId));
    }

    @Override
    public int logicDelByOrderId(Long orderId) {
        if (orderId == null) {
            return 0;
        }
        return prodProcessMapper.logicDelByOrderId(orderId);
    }

    @Override
    public List<ProdProcessVO> selectByIds(List<Long> ids) {
        if (CollectionUtils.isEmptyElement(ids)) {
            return Collections.emptyList();
        }

        ProdProcessQuery query = new ProdProcessQuery();
        query.setIds(ids);
        return selectProdProcessList(query);
    }

    @Override
    public int batchInsert(List<? extends ProdProcess> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        Date now = DateUtils.getNowDate();
        for (ProdProcess process : list) {
            process.setCreateTime(now);
        }
        return prodProcessMapper.batchInsert(list);
    }
}
